==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/StatefulRuleGroup.scala <==
package zio.aws.fms.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.fms.model.primitives.{
  PriorityNumber,
  ResourceId,
  NetworkFirewallResourceName
}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class StatefulRuleGroup(
    ruleGroupName: Optional[NetworkFirewallResourceName] = Optional.Absent,
    resourceId: Optional[ResourceId] = Optional.Absent,
    priority: Optional[PriorityNumber] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.StatefulRuleGroup = {
    import StatefulRuleGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.StatefulRuleGroup
      .builder()
      .optionallyWith(
        ruleGroupName.map(value =>
          NetworkFirewallResourceName.unwrap(value): java.lang.String
        )
      )(_.ruleGroupName)
      .optionallyWith(
        resourceId.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.resourceId)
      .optionallyWith(
        priority.map(value => PriorityNumber.unwrap(value): Integer)
      )(_.priority)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.StatefulRuleGroup.ReadOnly =
    zio.aws.fms.model.StatefulRuleGroup.wrap(buildAwsValue())
}
object StatefulRuleGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.StatefulRuleGroup =
      zio.aws.fms.model.StatefulRuleGroup(
        ruleGroupName.map(value => value),
        resourceId.map(value => value),
        priority.map(value => value)
      )
    def ruleGroupName: Optional[NetworkFirewallResourceName]
    def resourceId: Optional[ResourceId]
    def priority: Optional[PriorityNumber]
    def getRuleGroupName: ZIO[Any, AwsError, NetworkFirewallResourceName] =
      AwsError.unwrapOptionField("ruleGroupName", ruleGroupName)
    def getResourceId: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("resourceId", resourceId)
    def getPriority: ZIO[Any, AwsError, PriorityNumber] =
      AwsError.unwrapOptionField("priority", priority)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ) extends zio.aws.fms.model.StatefulRuleGroup.ReadOnly {
    override val ruleGroupName: Optional[NetworkFirewallResourceName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroupName())
        .map(value =>
          zio.aws.fms.model.primitives.NetworkFirewallResourceName(value)
        )
    override val resourceId: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceId())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val priority: Optional[PriorityNumber] = zio.aws.core.internal
      .optionalFromNullable(impl.priority())
      .map(value => zio.aws.fms.model.primitives.PriorityNumber(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ): zio.aws.fms.model.StatefulRuleGroup.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.126.2-sources.jar: zio/aws/fms/model/StatefulRuleGroup.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.{ResourceId, NetworkFirewallResourceName}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StatefulRuleGroup(
    ruleGroupName: Option[NetworkFirewallResourceName] = None,
    resourceId: Option[ResourceId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.StatefulRuleGroup = {
    import StatefulRuleGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.StatefulRuleGroup
      .builder()
      .optionallyWith(
        ruleGroupName.map(value =>
          NetworkFirewallResourceName.unwrap(value): java.lang.String
        )
      )(_.ruleGroupName)
      .optionallyWith(
        resourceId.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.resourceId)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.StatefulRuleGroup.ReadOnly =
    zio.aws.fms.model.StatefulRuleGroup.wrap(buildAwsValue())
}
object StatefulRuleGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.StatefulRuleGroup =
      zio.aws.fms.model.StatefulRuleGroup(
        ruleGroupName.map(value => value),
        resourceId.map(value => value)
      )
    def ruleGroupName: Option[NetworkFirewallResourceName]
    def resourceId: Option[ResourceId]
    def getRuleGroupName: ZIO[Any, AwsError, NetworkFirewallResourceName] =
      AwsError.unwrapOptionField("ruleGroupName", ruleGroupName)
    def getResourceId: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("resourceId", resourceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ) extends zio.aws.fms.model.StatefulRuleGroup.ReadOnly {
    override val ruleGroupName: Option[NetworkFirewallResourceName] = scala
      .Option(impl.ruleGroupName())
      .map(value =>
        zio.aws.fms.model.primitives.NetworkFirewallResourceName(value)
      )
    override val resourceId: Option[ResourceId] = scala
      .Option(impl.resourceId())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.StatefulRuleGroup
  ): zio.aws.fms.model.StatefulRuleGroup.ReadOnly = new Wrapper(impl)
}
